<?php
/**
 * The calendar widget functionality of the plugin.
 *
 * @link       https://wpextend.io
 * @since      1.0.0
 *
 * @package    Elementor_Connector_For_Woocommerce_Bookings
 * @subpackage Elementor_Connector_For_Woocommerce_Bookings/admin/partials
 */

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Popover_Toggle;
use Elementor\Group_Control_Box_Shadow;

// Design.
$this->add_control(
	'ecwb_calendar_styles_background_header',
	array(
		'label' => __( 'Design', 'elementor-connector-for-woocommerce-bookings' ),
		'type'  => Controls_Manager::HEADING,
	)
);

$this->add_control(
	'ecwb_calendar_styles_background_popover',
	array(
		'label' => __( 'Backgrounds', 'elementor-connector-for-woocommerce-bookings' ),
		'type'  => Controls_Manager::POPOVER_TOGGLE,
	)
);

$this->start_popover();

	$this->start_controls_tabs( 'ecwb_calendar_styles_background_tabs' );

		$this->start_controls_tab(
			'ecwb_calendar_styles_background_tabs_normal',
			array(
				'label' => __( 'Normal', 'elementor-connector-for-woocommerce-bookings' ),
			)
		);

			$this->add_control(
				'ecwb_calendar_styles_container_background',
				array(
					'label'     => __( 'Container', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-widget-content' => 'background: {{VALUE}}',
					),
					'condition' => array(
						'ecwb_calendar_styles_background_popover' => 'yes',
					),
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_monthheader_background',
				array(
					'label'     => __( 'Month Header', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker-header' => 'background: {{VALUE}}',
					),
					'condition' => array(
						'ecwb_calendar_styles_background_popover' => 'yes',
					),
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_nextprev_background',
				array(
					'label'     => __( 'Next/Previous Selectors', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker .ui-datepicker-next, {{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker .ui-datepicker-prev' => 'background: {{VALUE}}; opacity: 1;',
					),
					'condition' => array(
						'ecwb_calendar_styles_background_popover' => 'yes',
					),
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_dayheader_background',
				array(
					'label'     => __( 'Day Header', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker thead th' => 'background: {{VALUE}}',
					),
					'condition' => array(
						'ecwb_calendar_styles_background_popover' => 'yes',
					),
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_available_background',
				array(
					'label'     => __( 'Date(s) Available', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker td.bookable a' => 'background: {{VALUE}} !important',
					),
					'condition' => array(
						'ecwb_calendar_styles_background_popover' => 'yes',
					),
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_general_background',
				array(
					'label'     => __( 'Date(s) Unavailable', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker tbody td, {{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker tbody .ui-state-disabled' => 'background: {{VALUE}}',
					),
					'condition' => array(
						'ecwb_calendar_styles_background_popover' => 'yes',
					),
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_today_background',
				array(
					'label'     => __( 'Today\'s Date', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker td.ui-datepicker-today a' => 'background: {{VALUE}} !important',
					),
					'condition' => array(
						'ecwb_calendar_styles_background_popover' => 'yes',
					),
					'separator' => 'after',
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_unavailable_future_opacity',
				array(
					'label'      => esc_html__( 'Unavailable / Future Transparency', 'elementor-connector-for-woocommerce-bookings' ),
					'type'       => \Elementor\Controls_Manager::SLIDER,
					'size_units' => array( 'px' ),
					'range'      => array(
						'px' => array(
							'min'  => 0,
							'max'  => 1,
							'step' => 0.1,
						),
					),
					'default'    => array(
						'unit' => 'px',
						'size' => 1,
					),
					'selectors'  => array(
						'{{WRAPPER}} .ui-state-disabled, {{WRAPPER}} .ui-widget-content .ui-state-disabled, {{WRAPPER}} .ui-widget-header .ui-state-disabled, {{WRAPPER}} .ui-priority-secondary, {{WRAPPER}} .ui-widget-content .ui-priority-secondary, {{WRAPPER}} .ui-widget-header .ui-priority-secondary' => 'opacity: {{SIZE}};',
					),
				)
			);

			$this->end_controls_tab();

			$this->start_controls_tab(
				'ecwb_calendar_styles_background_tabs_hover',
				array(
					'label' => __( 'Hover', 'elementor-connector-for-woocommerce-bookings' ),
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_nextprev_background_hover',
				array(
					'label'     => __( 'Next/Previous Selectors', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker .ui-datepicker-next:hover, {{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker .ui-datepicker-prev:hover' => 'background: {{VALUE}};',
					),
					'condition' => array(
						'ecwb_calendar_styles_background_popover' => 'yes',
					),
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_available_background_hover',
				array(
					'label'     => __( 'Date(s) Available', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker td.bookable a:hover' => 'background: {{VALUE}} !important',
					),
					'condition' => array(
						'ecwb_calendar_styles_background_popover' => 'yes',
					),
				)
			);

			$this->end_controls_tab();

			$this->start_controls_tab(
				'ecwb_calendar_styles_background_tabs_selected',
				array(
					'label' => __( 'Select', 'elementor-connector-for-woocommerce-bookings' ),
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_range_background_selected',
				array(
					'label'     => __( 'Date(s) Selected', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker td.bookable a.ui-state-active, {{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker td.bookable-range a' => 'background: {{VALUE}} !important',
					),
					'condition' => array(
						'ecwb_calendar_styles_background_popover' => 'yes',
					),
				)
			);

			$this->end_controls_tab();

			$this->end_controls_tabs();

			$this->end_popover();

			$this->add_control(
				'ecwb_calendar_styles_border_popover',
				array(
					'label' => __( 'Borders', 'elementor-connector-for-woocommerce-bookings' ),
					'type'  => Controls_Manager::POPOVER_TOGGLE,
				)
			);

			$this->start_popover();

			$this->add_control(
				'ecwb_calendar_styles_container_border_header',
				array(
					'label'     => __( 'Booking Form Container', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
				)
			);

			$this->add_group_control(
				Group_Control_Border::get_type(),
				array(
					'name'        => 'ecwb_calendar_styles_container_border',
					'label'       => __( 'Booking Form Container', 'elementor-connector-for-woocommerce-bookings' ),
					'selector'    => '{{WRAPPER}} #wc-bookings-booking-form',
					'condition'   => array(
						'ecwb_calendar_styles_border_popover' => 'yes',
					),
					'separator'   => 'after',
					'description' => ' ',
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_monthheader_border_header',
				array(
					'label'     => __( 'Month Header', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
				)
			);

			$this->add_group_control(
				Group_Control_Border::get_type(),
				array(
					'name'        => 'ecwb_calendar_styles_monthheader_border',
					'label'       => __( 'Month Header', 'elementor-connector-for-woocommerce-bookings' ),
					'selector'    => '{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker-header',
					'condition'   => array(
						'ecwb_calendar_styles_border_popover' => 'yes',
					),
					'separator'   => 'after',
					'description' => ' ',
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_nextprev_border_header',
				array(
					'label'     => __( 'Next/Previous Selectors', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
				)
			);

			$this->add_group_control(
				Group_Control_Border::get_type(),
				array(
					'name'        => 'ecwb_calendar_styles_nextprev_border',
					'label'       => __( 'Next/Previous Selectors', 'elementor-connector-for-woocommerce-bookings' ),
					'selector'    => '{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker .ui-datepicker-next, {{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker .ui-datepicker-prev',
					'condition'   => array(
						'ecwb_calendar_styles_border_popover' => 'yes',
					),
					'separator'   => 'after',
					'description' => ' ',
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_general_border_header',
				array(
					'label'     => __( 'Calendar Dates', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
				)
			);

			$this->add_group_control(
				Group_Control_Border::get_type(),
				array(
					'name'        => 'ecwb_calendar_styles_general_border',
					'label'       => __( 'Dates', 'elementor-connector-for-woocommerce-bookings' ),
					'selector'    => '{{WRAPPER}} .wc-bookings-date-picker .ui-datepicker td, {{WRAPPER}} .wc-bookings-date-picker .ui-datepicker td.last, {{WRAPPER}} .wc-bookings-date-picker .ui-datepicker td.first',
					'condition'   => array(
						'ecwb_calendar_styles_border_popover' => 'yes',
					),
					'separator'   => 'after',
					'description' => ' ',
				)
			);

			$this->end_popover();

			$this->add_control(
				'ecwb_calendar_styles_border_radius_popover',
				array(
					'label' => __( 'Border Radius', 'elementor-connector-for-woocommerce-bookings' ),
					'type'  => Controls_Manager::POPOVER_TOGGLE,
				)
			);

			$this->start_popover();

			$this->add_responsive_control(
				'ecwb_calendar_styles_border_radius_header',
				array(
					'label'      => __( 'Month Header', 'elementor-connector-for-woocommerce-bookings' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => array( 'px' ),
					'default'    => array(
						'top'      => '',
						'right'    => '',
						'bottom'   => '',
						'left'     => '',
						'isLinked' => true,
					),
					'selectors'  => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker-header' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
					'condition'  => array(
						'ecwb_calendar_styles_border_radius_popover' => 'yes',
					),
				)
			);

			$this->add_responsive_control(
				'ecwb_calendar_styles_border_radius_dates',
				array(
					'label'      => __( 'Calendar Dates', 'elementor-connector-for-woocommerce-bookings' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => array( 'px' ),
					'default'    => array(
						'top'      => '',
						'right'    => '',
						'bottom'   => '',
						'left'     => '',
						'isLinked' => true,
					),
					'selectors'  => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker td.bookable a, {{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker td.bookable-range a, {{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker td.ui-datepicker-unselectable' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
					'condition'  => array(
						'ecwb_calendar_styles_border_radius_popover' => 'yes',
					),
				)
			);

			$this->end_popover();

			$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
				array(
					'name'     => 'ecwb_calendar_styles_box_shadow_calendar',
					'label'    => __( 'Box Shadow', 'elementor-connector-for-woocommerce-bookings' ),
					'selector' => '{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-widget-content',
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_layout_header',
				array(
					'label'     => __( 'Layout', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_margin_popover',
				array(
					'label' => __( 'Margin', 'elementor-connector-for-woocommerce-bookings' ),
					'type'  => Controls_Manager::POPOVER_TOGGLE,
				)
			);

			$this->start_popover();

			$this->add_responsive_control(
				'ecwb_calendar_styles_section_margin',
				array(
					'label'      => __( 'Booking Form Container', 'elementor-connector-for-woocommerce-bookings' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => array( 'px', 'em', '%' ),
					'selectors'  => array(
						'{{WRAPPER}} .wc-bookings-booking-form fieldset .picker.hasDatepicker' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
					'default'    => array(
						'top'      => '',
						'right'    => '',
						'bottom'   => '',
						'left'     => '',
						'isLinked' => true,
					),
					'condition'  => array(
						'ecwb_calendar_styles_margin_popover' => 'yes',
					),
				)
			);

			$this->add_responsive_control(
				'ecwb_calendar_styles_monthheader_margin',
				array(
					'label'      => __( 'Month Header', 'elementor-connector-for-woocommerce-bookings' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => array( 'px', 'em', '%' ),
					'selectors'  => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker-header' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
					'default'    => array(
						'top'      => '',
						'right'    => '',
						'bottom'   => '',
						'left'     => '',
						'isLinked' => true,
					),
					'condition'  => array(
						'ecwb_calendar_styles_margin_popover' => 'yes',
					),
				)
			);

			$this->end_popover();

			$this->add_control(
				'ecwb_calendar_styles_padding_popover',
				array(
					'label' => __( 'Padding', 'elementor-connector-for-woocommerce-bookings' ),
					'type'  => Controls_Manager::POPOVER_TOGGLE,
				)
			);

			$this->start_popover();

			$this->add_responsive_control(
				'ecwb_calendar_styles_section_padding',
				array(
					'label'      => __( 'Booking Form Container', 'elementor-connector-for-woocommerce-bookings' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => array( 'px', 'em', '%' ),
					'selectors'  => array(
						'{{WRAPPER}} .wc-bookings-booking-form fieldset.wc-bookings-date-picker, {{WRAPPER}} .wc-bookings-booking-form' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
					'default'    => array(
						'top'      => '',
						'right'    => '',
						'bottom'   => '',
						'left'     => '',
						'isLinked' => true,
					),
					'condition'  => array(
						'ecwb_calendar_styles_padding_popover' => 'yes',
					),
				)
			);

			$this->add_responsive_control(
				'ecwb_calendar_styles_monthheader_padding',
				array(
					'label'      => __( 'Month Header', 'elementor-connector-for-woocommerce-bookings' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => array( 'px', 'em', '%' ),
					'selectors'  => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker-header' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						'.wc-bookings-date-picker .ui-datepicker .ui-datepicker-prev, .wc-bookings-date-picker .ui-datepicker .ui-datepicker-next' => 'top: {{TOP}}{{UNIT}};',
						'.wc-bookings-date-picker .ui-datepicker .ui-datepicker-prev' => 'left: {{LEFT}}{{UNIT}};',
						'.wc-bookings-date-picker .ui-datepicker .ui-datepicker-next' => 'right: {{RIGHT}}{{UNIT}};',

					),
					'default'    => array(
						'top'      => '',
						'right'    => '',
						'bottom'   => '',
						'left'     => '',
						'isLinked' => true,
					),
					'condition'  => array(
						'ecwb_calendar_styles_padding_popover' => 'yes',
					),
				)
			);

			$this->add_responsive_control(
				'ecwb_calendar_styles_dates_padding',
				array(
					'label'      => __( 'Calendar Dates', 'elementor-connector-for-woocommerce-bookings' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => array( 'px', 'em', '%' ),
					'selectors'  => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker td.bookable a, {{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker td.bookable-range a, {{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker td span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
					),
					'default'    => array(
						'top'      => '',
						'right'    => '',
						'bottom'   => '',
						'left'     => '',
						'isLinked' => true,
					),
					'condition'  => array(
						'ecwb_calendar_styles_padding_popover' => 'yes',
					),
				)
			);

			$this->end_popover();

			$this->add_control(
				'ecwb_calendar_styles_typography_header',
				array(
					'label'     => __( 'Typography', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_typography_popover',
				array(
					'label' => __( 'Font Colors', 'elementor-connector-for-woocommerce-bookings' ),
					'type'  => Controls_Manager::POPOVER_TOGGLE,
				)
			);

			$this->start_popover();

			$this->start_controls_tabs( 'ecwb_calendar_styles_typography_tabs' );

			$this->start_controls_tab(
				'ecwb_calendar_styles_typography_tabs_normal',
				array(
					'label' => __( 'Normal', 'elementor-connector-for-woocommerce-bookings' ),
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_monthheader_typography_color',
				array(
					'label'     => __( 'Month Header', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::COLOR,

					'selectors' => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker-header .ui-datepicker-title span' => 'color: {{VALUE}}',
					),
					'condition' => array(
						'ecwb_calendar_styles_typography_popover' => 'yes',
					),
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_weekheader_typography_color',
				array(
					'label'     => __( 'Week Header', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::COLOR,

					'selectors' => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker thead th' => 'color: {{VALUE}}',
					),
					'condition' => array(
						'ecwb_calendar_styles_typography_popover' => 'yes',
					),
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_dates_unavailable_typography_color',
				array(
					'label'     => __( 'Date(s) Unavailable', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::COLOR,

					'selectors' => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker td span' => 'color: {{VALUE}}',
					),
					'condition' => array(
						'ecwb_calendar_styles_typography_popover' => 'yes',
					),
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_dates_available_typography_color',
				array(
					'label'     => __( 'Date(s) Available', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::COLOR,

					'selectors' => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker td.bookable a, {{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker td.bookable-range a' => 'color: {{VALUE}} !important',
					),
					'condition' => array(
						'ecwb_calendar_styles_typography_popover' => 'yes',
					),
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_todays_date_typography_color',
				array(
					'label'     => __( 'Today\'s Date', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::COLOR,

					'selectors' => array(
						'html body {{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker td.ui-datepicker-today a' => 'color: {{VALUE}} !important',
					),
					'condition' => array(
						'ecwb_calendar_styles_typography_popover' => 'yes',
					),
				)
			);

			$this->end_controls_tab();

			$this->start_controls_tab(
				'ecwb_calendar_styles_typography_tabs_hover',
				array(
					'label' => __( 'Hover', 'elementor-connector-for-woocommerce-bookings' ),
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_dates_available_typography_color_hover',
				array(
					'label'     => __( 'Date(s) Available', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::COLOR,

					'selectors' => array(
						'{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker td.bookable:hover a, {{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker td.bookable-range:hover a' => 'color: {{VALUE}} !important',
					),
					'condition' => array(
						'ecwb_calendar_styles_typography_popover' => 'yes',
					),
				)
			);

			$this->end_controls_tab();

			$this->start_controls_tab(
				'ecwb_calendar_styles_typography_tabs_select',
				array(
					'label' => __( 'Select', 'elementor-connector-for-woocommerce-bookings' ),
				)
			);

			$this->add_control(
				'ecwb_calendar_styles_dates_available_typography_color_select',
				array(
					'label'     => __( 'Date(s) Selected', 'elementor-connector-for-woocommerce-bookings' ),
					'type'      => Controls_Manager::COLOR,

					'selectors' => array(
						'body {{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker td.bookable a.ui-state-active, body {{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker td.bookable-range a.ui-state-default, body {{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker td.ui-datepicker-current-day a' => 'color: {{VALUE}} !important',
					),
					'condition' => array(
						'ecwb_calendar_styles_typography_popover' => 'yes',
					),
				)
			);

			$this->end_controls_tab();

			$this->end_controls_tabs();

			$this->end_popover();

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				array(
					'name'     => 'ecwb_calendar_styles_monthheader_typography',
					'label'    => __( 'Month Header Font', 'elementor-connector-for-woocommerce-bookings' ),
					'selector' => '{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker-header .ui-datepicker-title',
				)
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				array(
					'name'     => 'ecwb_calendar_styles_weekheader_typography',
					'label'    => __( 'Week Header Font', 'elementor-connector-for-woocommerce-bookings' ),
					'selector' => '{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker thead th',
				)
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				array(
					'name'     => 'ecwb_calendar_styles_dates_available_typography',
					'label'    => __( 'Date(s) Font', 'elementor-connector-for-woocommerce-bookings' ),
					'selector' => '{{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker td.bookable a, {{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker td.bookable-range a, {{WRAPPER}} #wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker td span',
				)
			);
