<?php
/**
 * The costs widget functionality of the plugin.
 *
 * @link       https://wpextend.io
 * @since      1.0.0
 *
 * @package    Elementor_Connector_For_Woocommerce_Bookings
 * @subpackage Elementor_Connector_For_Woocommerce_Bookings/admin/partials
 */

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Popover_Toggle;

// Design.
$this->add_control(
	'ecwb_costs_styles_background_header',
	array(
		'label' => __( 'Design', 'elementor-connector-for-woocommerce-bookings' ),
		'type'  => Controls_Manager::HEADING,
	)
);

$this->add_control(
	'ecwb_costs_styles_background_popover',
	array(
		'label' => __( 'Backgrounds', 'elementor-connector-for-woocommerce-bookings' ),
		'type'  => Controls_Manager::POPOVER_TOGGLE,
	)
);

$this->start_popover();

	$this->add_control(
		'ecwb_costs_styles_section_background',
		array(
			'label'     => __( 'Section Background', 'elementor-connector-for-woocommerce-bookings' ),
			'type'      => Controls_Manager::COLOR,
			'default'   => '',
			'selectors' => array(
				'{{WRAPPER}} form.cart .wc-bookings-booking-cost' => 'background: {{VALUE}}',
			),
			'condition' => array(
				'ecwb_costs_styles_background_popover' => 'yes',
			),
		)
	);

	$this->end_popover();

	$this->add_control(
		'ecwb_costs_styles_border_popover',
		array(
			'label' => __( 'Borders', 'elementor-connector-for-woocommerce-bookings' ),
			'type'  => Controls_Manager::POPOVER_TOGGLE,
		)
	);

	$this->start_popover();

	$this->add_group_control(
		Group_Control_Border::get_type(),
		array(
			'name'      => 'ecwb_costs_styles_section_border',
			'label'     => __( 'Section Border', 'elementor-connector-for-woocommerce-bookings' ),
			'selector'  => '{{WRAPPER}} form.cart .wc-bookings-booking-cost',
			'separator' => 'after',
			'condition' => array(
				'ecwb_costs_styles_border_popover' => 'yes',
			),
		)
	);

	$this->add_responsive_control(
		'ecwb_costs_styles_section_border_radius',
		array(
			'label'      => __( 'Section Border Radius', 'elementor-connector-for-woocommerce-bookings' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => array( 'px' ),
			'default'    => array(
				'top'      => '',
				'right'    => '',
				'bottom'   => '',
				'left'     => '',
				'isLinked' => true,
			),
			'selectors'  => array(
				'{{WRAPPER}} form.cart .wc-bookings-booking-cost' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			),
			'condition'  => array(
				'ecwb_costs_styles_border_popover' => 'yes',
			),
		)
	);

	$this->end_popover();

	// Layout.
	$this->add_control(
		'ecwb_costs_styles_layout_header',
		array(
			'label'     => __( 'Layout', 'elementor-connector-for-woocommerce-bookings' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
		)
	);

	$this->add_control(
		'ecwb_costs_styles_margin_popover',
		array(
			'label' => __( 'Margin', 'elementor-connector-for-woocommerce-bookings' ),
			'type'  => Controls_Manager::POPOVER_TOGGLE,
		)
	);

	$this->start_popover();

	$this->add_responsive_control(
		'ecwb_buttons_styles_section_margin',
		array(
			'label'      => __( 'Section Margin', 'elementor-connector-for-woocommerce-bookings' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => array( 'px', 'em', '%' ),
			'selectors'  => array(
				'form.cart .wc-bookings-booking-cost' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			),
			'default'    => array(
				'top'      => '',
				'right'    => '',
				'bottom'   => '',
				'left'     => '',
				'isLinked' => true,
			),
			'condition'  => array(
				'ecwb_costs_styles_margin_popover' => 'yes',
			),
		)
	);

	$this->end_popover();

	$this->add_control(
		'ecwb_costs_styles_padding_popover',
		array(
			'label' => __( 'Padding', 'elementor-connector-for-woocommerce-bookings' ),
			'type'  => Controls_Manager::POPOVER_TOGGLE,
		)
	);

	$this->start_popover();

	$this->add_responsive_control(
		'ecwb_buttons_styles_section_padding',
		array(
			'label'      => __( 'Section Padding', 'elementor-connector-for-woocommerce-bookings' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => array( 'px', 'em', '%' ),
			'selectors'  => array(
				'{{WRAPPER}} form.cart .wc-bookings-booking-cost' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			),
			'default'    => array(
				'top'      => '',
				'right'    => '',
				'bottom'   => '',
				'left'     => '',
				'isLinked' => true,
			),
			'condition'  => array(
				'ecwb_costs_styles_padding_popover' => 'yes',
			),
		)
	);

	$this->end_popover();

	$this->add_control(
		'ecwb_costs_styles_dimensions_popover',
		array(
			'label' => __( 'Dimensions', 'elementor-connector-for-woocommerce-bookings' ),
			'type'  => Controls_Manager::POPOVER_TOGGLE,
		)
	);

	$this->start_popover();

	$this->add_responsive_control(
		'ecwb_costs_styles_section_width',
		array(
			'label'      => __( 'Section Width', 'elementor-connector-for-woocommerce-bookings' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => array( 'px', '%' ),
			'range'      => array(
				'px' => array(
					'min'  => 0,
					'max'  => 960,
					'step' => 5,
				),
				'%'  => array(
					'min' => 0,
					'max' => 100,
				),
			),
			'selectors'  => array(
				'{{WRAPPER}} form.cart .wc-bookings-booking-cost' => 'width: {{SIZE}}{{UNIT}};',
			),
			'condition'  => array(
				'ecwb_costs_styles_dimensions_popover' => 'yes',
			),
		)
	);

	$this->end_popover();

	// Typography.
	$this->add_control(
		'ecwb_costs_styles_typography_header',
		array(
			'label'     => __( 'Typograpy', 'elementor-connector-for-woocommerce-bookings' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
		)
	);

	$this->add_control(
		'ecwb_costs_styles_typography_popover',
		array(
			'label' => __( 'Font Colors', 'elementor-connector-for-woocommerce-bookings' ),
			'type'  => Controls_Manager::POPOVER_TOGGLE,
		)
	);

	$this->start_popover();

	$this->add_control(
		'ecwb_costs_styles_label_typography_color',
		array(
			'label'     => __( 'Label Color', 'elementor-connector-for-woocommerce-bookings' ),
			'type'      => Controls_Manager::COLOR,

			'selectors' => array(
				'{{WRAPPER}} form.cart .wc-bookings-booking-cost' => 'color: {{VALUE}}',
			),
			'condition' => array(
				'ecwb_costs_styles_typography_popover' => 'yes',
			),
		)
	);

	$this->add_control(
		'ecwb_costs_styles_field_typography_color',
		array(
			'label'     => __( 'Cost Color', 'elementor-connector-for-woocommerce-bookings' ),
			'type'      => Controls_Manager::COLOR,

			'selectors' => array(
				'{{WRAPPER}} form.cart .wc-bookings-booking-cost strong span' => 'color: {{VALUE}}',
			),
			'condition' => array(
				'ecwb_costs_styles_typography_popover' => 'yes',
			),
		)
	);

	$this->end_popover();

	$this->add_group_control(
		Group_Control_Typography::get_type(),
		array(
			'name'     => 'ecwb_costs_styles_label_typography',
			'label'    => __( 'Label Font', 'elementor-connector-for-woocommerce-bookings' ),
			'selector' => '{{WRAPPER}} form.cart .wc-bookings-booking-cost',
		)
	);

	$this->add_group_control(
		Group_Control_Typography::get_type(),
		array(
			'name'     => 'ecwb_costs_styles_field_typography',
			'label'    => __( 'Cost Font', 'elementor-connector-for-woocommerce-bookings' ),
			'selector' => '{{WRAPPER}} form.cart .wc-bookings-booking-cost strong span',
		)
	);
