<?php
/**
 * The resources widget functionality of the plugin.
 *
 * @link       https://wpextend.io
 * @since      1.0.0
 *
 * @package    Elementor_Connector_For_Woocommerce_Bookings
 * @subpackage Elementor_Connector_For_Woocommerce_Bookings/admin/partials
 */

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Popover_Toggle;

// Design.
$this->add_control(
	'ecwb_resource_styles_design_header',
	array(
		'label' => __( 'Design', 'elementor-connector-for-woocommerce-bookings' ),
		'type'  => Controls_Manager::HEADING,
	)
);

$this->add_control(
	'ecwb_resource_styles_background_popover',
	array(
		'label' => __( 'Backgrounds', 'elementor-connector-for-woocommerce-bookings' ),
		'type'  => Controls_Manager::POPOVER_TOGGLE,
	)
);

$this->start_popover();

$this->start_controls_tabs( 'ecwb_resource_styles_background_tabs' );

$this->start_controls_tab(
	'ecwb_resource_styles_background_tabs_normal',
	array(
		'label' => __( 'Normal', 'elementor-connector-for-woocommerce-bookings' ),
	)
);

	$this->add_control(
		'ecwb_resource_styles_section_background',
		array(
			'label'     => __( 'Section Background', 'elementor-connector-for-woocommerce-bookings' ),
			'type'      => Controls_Manager::COLOR,
			'default'   => '',
			'selectors' => array(
				'{{WRAPPER}} #wc-bookings-booking-form p[class*="wc_bookings_field_resource"]' => 'background: {{VALUE}}',
			),
			'condition' => array(
				'ecwb_resource_styles_background_popover' => 'yes',
			),
		)
	);

	$this->add_control(
		'ecwb_resource_styles_field_background',
		array(
			'label'     => __( 'Dropdown Background', 'elementor-connector-for-woocommerce-bookings' ),
			'type'      => Controls_Manager::COLOR,
			'default'   => '',
			'selectors' => array(
				'{{WRAPPER}} .select2-container--default .select2-selection--single, {{WRAPPER}} .select2-container--default .select2-results__option[aria-selected=true], .select2-container--default .select2-results__option[data-selected=true], .select2-results__option, .select2-search--dropdown' => 'background: {{VALUE}}',
			),
			'condition' => array(
				'ecwb_resource_styles_background_popover' => 'yes',
			),
		)
	);

	$this->end_controls_tab();

	$this->start_controls_tab(
		'ecwb_resource_styles_background_tabs_hover',
		array(
			'label' => __( 'Hover', 'elementor-connector-for-woocommerce-bookings' ),
		)
	);

	$this->add_control(
		'ecwb_resource_styles_section_background_hover',
		array(
			'label'     => __( 'Section Background', 'elementor-connector-for-woocommerce-bookings' ),
			'type'      => Controls_Manager::COLOR,
			'default'   => '',
			'selectors' => array(
				'{{WRAPPER}} {{WRAPPER}} #wc-bookings-booking-form p[class*="wc_bookings_field_resource"]:hover' => 'background: {{VALUE}}',
			),
			'condition' => array(
				'ecwb_person_styles_background_popover' => 'yes',
			),
		)
	);

	$this->add_control(
		'ecwb_resource_styles_field_background_hover',
		array(
			'label'     => __( 'Dropdown Background', 'elementor-connector-for-woocommerce-bookings' ),
			'type'      => Controls_Manager::COLOR,
			'default'   => '',
			'selectors' => array(
				'{{WRAPPER}} .select2-container--default .select2-results__option[aria-selected=true]:hover, .select2-container--default .select2-results__option[data-selected=true]:hover, .select2-results__option:hover, .select2-container--default .select2-results__option--highlighted[aria-selected]:hover, .select2-container--default .select2-results__option--highlighted[data-selected]:hover' => 'background-color: {{VALUE}}',
			),
			'condition' => array(
				'ecwb_resource_styles_background_popover' => 'yes',
			),
		)
	);

	$this->end_controls_tab();

	$this->end_controls_tabs();

	$this->end_popover();

	$this->add_control(
		'ecwb_resource_styles_border_popover',
		array(
			'label' => __( 'Borders', 'elementor-connector-for-woocommerce-bookings' ),
			'type'  => Controls_Manager::POPOVER_TOGGLE,
		)
	);

	$this->start_popover();

	$this->start_controls_tabs( 'ecwb_resource_styles_border_tabs' );

	$this->start_controls_tab(
		'ecwb_resource_styles_border_tabs_normal',
		array(
			'label' => __( 'Normal', 'elementor-connector-for-woocommerce-bookings' ),
		)
	);

	$this->add_group_control(
		Group_Control_Border::get_type(),
		array(
			'name'      => 'ecwb_resource_styles_field_border',
			'label'     => __( 'Field Border', 'elementor-connector-for-woocommerce-bookings' ),
			'selector'  => '{{WRAPPER}} .select2-container--default .select2-selection--single, .select2-container--default .select2-search--dropdown .select2-search__field, .select2-dropdown',
			'condition' => array(
				'ecwb_resource_styles_border_popover' => 'yes',
			),
			'separator' => 'after',
		)
	);

	$this->end_controls_tab();

	$this->start_controls_tab(
		'ecwb_resource_styles_border_tabs_focus',
		array(
			'label' => __( 'Focus', 'elementor-connector-for-woocommerce-bookings' ),
		)
	);

	$this->add_group_control(
		Group_Control_Border::get_type(),
		array(
			'name'      => 'ecwb_resource_styles_field_border_focus',
			'label'     => __( 'Field Border', 'elementor-connector-for-woocommerce-bookings' ),
			'selector'  => '.select2-search--dropdown .select2-search__field:focus, .select2-container--default .select2-search--dropdown .select2-search__field:focus',
			'condition' => array(
				'ecwb_resource_styles_border_popover' => 'yes',
			),
			'separator' => 'after',
		)
	);

	$this->end_controls_tab();

	$this->end_controls_tabs();

	$this->add_responsive_control(
		'ecwb_resource_styles_field_border_radius',
		array(
			'label'      => __( 'Field Border Radius', 'elementor-connector-for-woocommerce-bookings' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => array( 'px' ),
			'default'    => array(
				'top'      => '',
				'right'    => '',
				'bottom'   => '',
				'left'     => '',
				'isLinked' => true,
			),
			'selectors'  => array(
				'{{WRAPPER}} .select2-container--default .select2-selection--single' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			),
			'condition'  => array(
				'ecwb_person_styles_border_popover' => 'yes',
			),
		)
	);

	$this->end_popover();

	// Layout.
	$this->add_control(
		'ecwb_resource_styles_layout_header',
		array(
			'label'     => __( 'Layout', 'elementor-connector-for-woocommerce-bookings' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
		)
	);

	$this->add_control(
		'ecwb_resource_styles_margin_popover',
		array(
			'label' => __( 'Margins', 'elementor-connector-for-woocommerce-bookings' ),
			'type'  => Controls_Manager::POPOVER_TOGGLE,
		)
	);

	$this->start_popover();

	$this->add_responsive_control(
		'ecwb_resource_styles_spacing_section_margin',
		array(
			'label'      => __( 'Section Margin', 'elementor-connector-for-woocommerce-bookings' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => array( 'px', 'em', '%' ),
			'selectors'  => array(
				'{{WRAPPER}} #wc-bookings-booking-form p[class*="wc_bookings_field_resource"]' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			),
			'default'    => array(
				'top'      => '',
				'right'    => '',
				'bottom'   => '',
				'left'     => '',
				'isLinked' => true,
			),
			'condition'  => array(
				'ecwb_resource_styles_margin_popover' => 'yes',
			),
		)
	);

	$this->add_responsive_control(
		'ecwb_resource_styles_spacing_label_margin',
		array(
			'label'      => __( 'Label Margin', 'elementor-connector-for-woocommerce-bookings' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => array( 'px', 'em', '%' ),
			'selectors'  => array(
				'{{WRAPPER}} #wc-bookings-booking-form p[class*="wc_bookings_field_resource"] label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			),
			'default'    => array(
				'top'      => '',
				'right'    => '',
				'bottom'   => '',
				'left'     => '',
				'isLinked' => true,
			),
			'condition'  => array(
				'ecwb_resource_styles_margin_popover' => 'yes',
			),
		)
	);

	$this->end_popover();

	$this->add_control(
		'ecwb_resource_styles_padding_popover',
		array(
			'label' => __( 'Padding', 'elementor-connector-for-woocommerce-bookings' ),
			'type'  => Controls_Manager::POPOVER_TOGGLE,
		)
	);

	$this->start_popover();

	$this->add_responsive_control(
		'ecwb_resource_styles_spacing_section_padding',
		array(
			'label'      => __( 'Section Padding', 'elementor-connector-for-woocommerce-bookings' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => array( 'px', 'em', '%' ),
			'selectors'  => array(
				'{{WRAPPER}} #wc-bookings-booking-form p[class*="wc_bookings_field_resource"]' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			),
			'default'    => array(
				'top'      => '',
				'right'    => '',
				'bottom'   => '',
				'left'     => '',
				'isLinked' => true,
			),
			'condition'  => array(
				'ecwb_resource_styles_padding_popover' => 'yes',
			),
		)
	);

	$this->add_responsive_control(
		'ecwb_resource_styles_spacing_label_padding',
		array(
			'label'      => __( 'Label Padding', 'elementor-connector-for-woocommerce-bookings' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => array( 'px', 'em', '%' ),
			'selectors'  => array(
				'{{WRAPPER}} #wc-bookings-booking-form p[class*="wc_bookings_field_resource"] label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			),
			'default'    => array(
				'top'      => '',
				'right'    => '',
				'bottom'   => '',
				'left'     => '',
				'isLinked' => true,
			),
			'condition'  => array(
				'ecwb_resource_styles_padding_popover' => 'yes',
			),
		)
	);

	$this->add_responsive_control(
		'ecwb_resource_styles_spacing_dropdown_padding',
		array(
			'label'      => __( 'Dropdown Padding', 'elementor-connector-for-woocommerce-bookings' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => array( 'px', 'em', '%' ),
			'selectors'  => array(
				'{{WRAPPER}} .select2-container--default .select2-selection--single' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			),
			'default'    => array(
				'top'      => '',
				'right'    => '',
				'bottom'   => '',
				'left'     => '',
				'isLinked' => true,
			),
			'condition'  => array(
				'ecwb_resource_styles_padding_popover' => 'yes',
			),
		)
	);

	$this->end_popover();

	$this->add_control(
		'ecwb_resource_styles_dimensions_popover',
		array(
			'label' => __( 'Dimensions', 'elementor-connector-for-woocommerce-bookings' ),
			'type'  => Controls_Manager::POPOVER_TOGGLE,
		)
	);

	$this->start_popover();

	$this->add_responsive_control(
		'ecwb_resource_styles_section_width',
		array(
			'label'      => __( 'Section Width', 'elementor-connector-for-woocommerce-bookings' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => array( 'px', '%' ),
			'range'      => array(
				'px' => array(
					'min'  => 0,
					'max'  => 1440,
					'step' => 5,
				),
				'%'  => array(
					'min' => 0,
					'max' => 100,
				),
			),
			'default'    => array(
				'unit' => '%',
				'size' => 100,
			),
			'selectors'  => array(
				'{{WRAPPER}} #wc-bookings-booking-form p[class*="wc_bookings_field_resource"], {{WRAPPER}} .wc-bookings-booking-form select, .select2-container--open .select2-dropdown--below' => 'width: {{SIZE}}{{UNIT}};',
			),
			'condition'  => array(
				'ecwb_resource_styles_dimensions_popover' => 'yes',
			),
		)
	);

	$this->add_responsive_control(
		'ecwb_resource_styles_field_height',
		array(
			'label'      => __( 'Dropdown Field Height', 'elementor-connector-for-woocommerce-bookings' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => array( 'px', '%', 'em' ),
			'range'      => array(
				'px' => array(
					'min'  => 0,
					'max'  => 1440,
					'step' => 5,
				),
				'%'  => array(
					'min' => 0,
					'max' => 100,
				),
			),
			'default'    => array(
				'unit' => 'px',
				'size' => 28,
			),
			'selectors'  => array(
				'{{WRAPPER}} .select2-container--default .select2-selection--single, {{WRAPPER}} .select2-container--default .select2-selection--single .select2-selection__arrow' => 'height: {{SIZE}}{{UNIT}};',
			),
			'condition'  => array(
				'ecwb_resource_styles_dimensions_popover' => 'yes',
			),
		)
	);

	$this->end_popover();

	// Typography.
	$this->add_control(
		'ecwb_resource_styles_typography_header',
		array(
			'label'     => __( 'Typography', 'elementor-connector-for-woocommerce-bookings' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
		)
	);

	$this->add_control(
		'ecwb_resource_styles_typography_popover',
		array(
			'label' => __( 'Font Colors', 'elementor-connector-for-woocommerce-bookings' ),
			'type'  => Controls_Manager::POPOVER_TOGGLE,
		)
	);

	$this->start_popover();

	$this->add_control(
		'ecwb_resource_styles_label_typography_color',
		array(
			'label'     => __( 'Label Color', 'elementor-connector-for-woocommerce-bookings' ),
			'type'      => Controls_Manager::COLOR,

			'selectors' => array(
				'{{WRAPPER}} #wc-bookings-booking-form p[class*="wc_bookings_field_resource"] label' => 'color: {{VALUE}}',
			),
			'condition' => array(
				'ecwb_resource_styles_typography_popover' => 'yes',
			),
		)
	);

	$this->add_control(
		'ecwb_resource_styles_dropdown_typography_color',
		array(
			'label'     => __( 'Dropdown Color', 'elementor-connector-for-woocommerce-bookings' ),
			'type'      => Controls_Manager::COLOR,

			'selectors' => array(
				'#select2-wc_bookings_field_resource-results .select2-results__option[aria-selected], #select2-wc_bookings_field_resource-results .select2-results__option[data-selected], .select2-container--default .select2-selection--single .select2-selection__rendered' => 'color: {{VALUE}}',
			),
			'condition' => array(
				'ecwb_resource_styles_typography_popover' => 'yes',
			),
		)
	);

	$this->end_popover();

	$this->add_group_control(
		Group_Control_Typography::get_type(),
		array(
			'name'     => 'ecwb_resource_styles_label_typography',
			'label'    => __( 'Label Font', 'elementor-connector-for-woocommerce-bookings' ),
			'selector' => '{{WRAPPER}} #wc-bookings-booking-form p[class*="wc_bookings_field_resource"] label',
		)
	);

	$this->add_group_control(
		Group_Control_Typography::get_type(),
		array(
			'name'     => 'ecwb_resource_styles_dropdown_typography',
			'label'    => __( 'Dropdown Font', 'elementor-connector-for-woocommerce-bookings' ),
			'selector' => '#select2-wc_bookings_field_resource-results .select2-results__option[aria-selected], #select2-wc_bookings_field_resource-results .select2-results__option[data-selected], .select2-container--default .select2-selection--single .select2-selection__rendered',
		)
	);
